COnfigure NVGRenderStage in wsini.ini, and tweak some comments
authorWilliam Roberts <williamr@symbian.org>
Tue, 05 Jan 2010 09:38:15 +0000
changeset 15 1bd1043e4812
parent 14 dfd4516c2f08
child 16 8788585969bc
COnfigure NVGRenderStage in wsini.ini, and tweak some comments
uiconfig/s60config/src/hw_wsini.ini
uiconfig/s60config/src/wsini_iti.ini
uigraphics/NVGRenderStage/res/nvgrenderstage.rss
uigraphics/NVGRenderStage/src/nvgrenderstage.cpp
uigraphics/NVGRenderStage/src/nvgrenderstage.h
uigraphics/NVGRenderStage/src/nvgrenderstagefactory.cpp
uigraphics/NVGRenderStage/src/nvgrenderstagefactory.h
uigraphics/NVGRenderStage/src/nvgrenderstagepanic.h
uigraphics/NVGRenderStage/src/nvgrenderstageplugin.cpp
Binary file uiconfig/s60config/src/hw_wsini.ini has changed
Binary file uiconfig/s60config/src/wsini_iti.ini has changed
--- a/uigraphics/NVGRenderStage/res/nvgrenderstage.rss	Mon Jan 04 21:58:13 2010 +0000
+++ b/uigraphics/NVGRenderStage/res/nvgrenderstage.rss	Tue Jan 05 09:38:15 2010 +0000
@@ -1,6 +1,6 @@
 // nvgrenderstage.rss
 
-// Copyright (c) 2008-2009 Nokia Corporation and/or its subsidiary(-ies).
+// Copyright (c) 2008-2010 Nokia Corporation and/or its subsidiary(-ies).
 // All rights reserved.
 // This component and the accompanying materials are made available
 // under the terms of "Eclipse Public License v1.0"
--- a/uigraphics/NVGRenderStage/src/nvgrenderstage.h	Mon Jan 04 21:58:13 2010 +0000
+++ b/uigraphics/NVGRenderStage/src/nvgrenderstage.h	Tue Jan 05 09:38:15 2010 +0000
@@ -1,4 +1,4 @@
-// Copyright (c) 2008-2009 Nokia Corporation and/or its subsidiary(-ies).
+// Copyright (c) 2008-2010 Nokia Corporation and/or its subsidiary(-ies).
 // All rights reserved.
 // This component and the accompanying materials are made available
 // under the terms of "Eclipse Public License v1.0"
--- a/uigraphics/NVGRenderStage/src/nvgrenderstagefactory.cpp	Mon Jan 04 21:58:13 2010 +0000
+++ b/uigraphics/NVGRenderStage/src/nvgrenderstagefactory.cpp	Tue Jan 05 09:38:15 2010 +0000
@@ -1,4 +1,4 @@
-// Copyright (c) 2008-2009 Nokia Corporation and/or its subsidiary(-ies).
+// Copyright (c) 2008-2010 Nokia Corporation and/or its subsidiary(-ies).
 // All rights reserved.
 // This component and the accompanying materials are made available
 // under the terms of "Eclipse Public License v1.0"
--- a/uigraphics/NVGRenderStage/src/nvgrenderstagefactory.h	Mon Jan 04 21:58:13 2010 +0000
+++ b/uigraphics/NVGRenderStage/src/nvgrenderstagefactory.h	Tue Jan 05 09:38:15 2010 +0000
@@ -1,4 +1,4 @@
-// Copyright (c) 2008-2009 Nokia Corporation and/or its subsidiary(-ies).
+// Copyright (c) 2008-2010 Nokia Corporation and/or its subsidiary(-ies).
 // All rights reserved.
 // This component and the accompanying materials are made available
 // under the terms of "Eclipse Public License v1.0"
--- a/uigraphics/NVGRenderStage/src/nvgrenderstagepanic.h	Mon Jan 04 21:58:13 2010 +0000
+++ b/uigraphics/NVGRenderStage/src/nvgrenderstagepanic.h	Tue Jan 05 09:38:15 2010 +0000
@@ -1,4 +1,4 @@
-// Copyright (c) 2008-2009 Nokia Corporation and/or its subsidiary(-ies).
+// Copyright (c) 2008-2010 Nokia Corporation and/or its subsidiary(-ies).
 // All rights reserved.
 // This component and the accompanying materials are made available
 // under the terms of "Eclipse Public License v1.0"
--- a/uigraphics/NVGRenderStage/src/nvgrenderstageplugin.cpp	Mon Jan 04 21:58:13 2010 +0000
+++ b/uigraphics/NVGRenderStage/src/nvgrenderstageplugin.cpp	Tue Jan 05 09:38:15 2010 +0000
@@ -1,4 +1,4 @@
-// Copyright (c) 2008-2009 Nokia Corporation and/or its subsidiary(-ies).
+// Copyright (c) 2008-2010 Nokia Corporation and/or its subsidiary(-ies).
 // All rights reserved.
 // This component and the accompanying materials are made available
 // under the terms of "Eclipse Public License v1.0"
--- a/uigraphics/NVGRenderStage/src/nvgrenderstage.cpp	Mon Jan 04 21:58:13 2010 +0000
+++ b/uigraphics/NVGRenderStage/src/nvgrenderstage.cpp	Tue Jan 05 09:38:15 2010 +0000
@@ -99,7 +99,7 @@
 and is used for all subsequent MWsGraphicsContext operations called on this
 render stage. 
 
-This render stage draws all extended bitmaps of type 0x10285A78
+This render stage draws all extended bitmaps of type 0x39b9273e
 and passes all other drawing operations directly to the next render stage through
 its MWsGraphicsContext interface.
 
@@ -146,7 +146,7 @@
 		}
 	}
 
 /** If the passed bitmap is an extended bitmap of type 0x10285A78, draw it to the stored
 graphics context of the next render stage using  DrawExtendedBitmap(), if the passed bitmap
 is not an extended bitmap just pass it on to the next render stage directly.
 
@@ -168,7 +168,7 @@
 		}
 	}
 
 /** If the passed bitmap is an extended bitmap of type 0x10285A78, draw it to the 
 stored graphics context of the next render stage using  DrawExtendedBitmap(), if the
 passed bitmap is not an extended bitmap just pass it on to the next render stage directly.
 
@@ -190,7 +190,7 @@
 		}
 	}
 
 /** If either of the passed bitmaps is an extended bitmap of type 0x10285A78 convert
 to a normal bitmap before passing to the next render stage, otherwise
 just pass to the next render stage directly.
 
@@ -219,7 +219,7 @@
 		}
 	}
 
 /** If either of the passed bitmaps is an extended bitmap of type 0x10285A78
 convert to a normal bitmap before passing to the next render stage, otherwise
 just pass to the next render stage directly.
 
@@ -318,7 +318,7 @@
 		}
 	}
 
 /** If the passed bitmap is an extended bitmap of type 0x10285A78, draw it to the 
 stored graphics context of the next render stage using DrawExtendedBitmap(), if the
 passed bitmap is not an extended bitmap just pass it on to the next render stage directly.
 
@@ -340,7 +340,7 @@
 		}
 	}
 
 /** If the passed bitmap is an extended bitmap of type 0x10285A78, draw it to the 
 stored graphics context of the next render stage using DrawExtendedBitmap(), if the
 passed bitmap is not an extended bitmap just pass it on to the next render stage directly.
 
@@ -362,7 +362,7 @@
 		}
 	}
 
 /** If the passed bitmap or mask bitmap is an extended bitmap of type 0x10285A78
 convert it to a normal bitmap before calling DrawBitmapMasked(), normal bitmaps
 are passed straight through to the next render stage without conversion.
 
@@ -755,7 +755,7 @@
 		}
 	}
 
 /** If the passed bitmap is an extended bitmap of type 0x10285A78
 convert the extended bitmap to a normal bitmap and set the converted bitmap
 as the current brush pattern. If the passed bitmap is a normal
 bitmap just pass it on to the next render stage.
@@ -768,7 +768,7 @@
 	SetBrushPattern(aBitmap.Handle());	
 	}
 
 /** If the passed bitmap handle refers to an extended bitmap of type 0x10285A78
 convert the extended bitmap to a normal bitmap and set the converted bitmap
 as the current brush pattern. If the passed bitmap handle refers to a normal
 bitmap just pass it on to the next render stage.
@@ -988,9 +988,9 @@
 
 @param aGc The graphics context to draw the extended bitmap to.
 @param aDestRect The rectangle that the source bitmap will be drawn to.
-@param aSourceBitmap The extended bitmap of type 0x10285A78 to be drawn.
+@param aSourceBitmap The extended bitmap of type 0x39b9273e to be drawn.
 
-@pre aSourceBitmap must be an extended bitmap of type 0x10285A78.
+@pre aSourceBitmap must be an extended bitmap of type 0x39b9273e.
 @post Sets an error that can be retrieved using GetError() is an error occurs. 
  */
 void CNvgRenderStage::DrawExtendedBitmap(MWsGraphicsContext& aGc, const TRect& aDestRect, const CFbsBitmap& aSourceBitmap)
@@ -1003,9 +1003,9 @@
 
 @param aGc The graphics context to draw the extended bitmap to.
 @param aDestRect The rectangle that the source bitmap will be drawn to.
-@param aSourceBitmap The extended bitmap of type 0x10285A78 to be drawn.
+@param aSourceBitmap The extended bitmap of type 0x39b9273e to be drawn.
 
-@pre aSourceBitmap must be an extended bitmap of type 0x10285A78.
+@pre aSourceBitmap must be an extended bitmap of type 0x39b9273e.
 @post Sets an error that can be retrieved using GetError() is an error occurs. 
  */
 void CNvgRenderStage::DrawExtendedBitmap(CFbsBitGc& aGc, const TRect& aDestRect, const CFbsBitmap& aSourceBitmap)
@@ -1021,7 +1021,7 @@
 @param aExtendedBitmapSrc The extended bitmap to draw in to the normal bitmap aBitmapDest
 @param aBitmapDest The normal bitmap that the extended bitmap is to be drawn into
 
-@pre aExtendedBitmapSrc must be an extended bitmap of extended bitmap type 0x10285A78
+@pre aExtendedBitmapSrc must be an extended bitmap of extended bitmap type 0x39b9273e
 @post aBitmapDest has been reset and resized and now contains a representation of the aExtendedBitmapSrc
  */
 void CNvgRenderStage::CopyExtendedBitmapToNormalBitmap(const CFbsBitmap& aExtendedBitmapSrc, CFbsBitmap& aBitmapDst)
@@ -146,7 +146,7 @@
 	}
 
-/** If the passed bitmap is an extended bitmap of type 0x10285A78, draw it to the stored
+/** If the passed bitmap is an extended bitmap of type 0x39b9273e, draw it to the stored
 graphics context of the next render stage using  DrawExtendedBitmap(), if the passed bitmap
 is not an extended bitmap just pass it on to the next render stage directly.
@@ -168,7 +168,7 @@
 	}
 
-/** If the passed bitmap is an extended bitmap of type 0x10285A78, draw it to the 
+/** If the passed bitmap is an extended bitmap of type 0x39b9273e, draw it to the 
 stored graphics context of the next render stage using  DrawExtendedBitmap(), if the
 passed bitmap is not an extended bitmap just pass it on to the next render stage directly.
@@ -190,7 +190,7 @@
 	}
 
-/** If either of the passed bitmaps is an extended bitmap of type 0x10285A78 convert
+/** If either of the passed bitmaps is an extended bitmap of type 0x39b9273e convert
 to a normal bitmap before passing to the next render stage, otherwise
 just pass to the next render stage directly.
@@ -219,7 +219,7 @@
 	}
 
-/** If either of the passed bitmaps is an extended bitmap of type 0x10285A78
+/** If either of the passed bitmaps is an extended bitmap of type 0x39b9273e
 convert to a normal bitmap before passing to the next render stage, otherwise
 just pass to the next render stage directly.
@@ -318,7 +318,7 @@
 	}
 
-/** If the passed bitmap is an extended bitmap of type 0x10285A78, draw it to the 
+/** If the passed bitmap is an extended bitmap of type 0x39b9273e, draw it to the 
 stored graphics context of the next render stage using DrawExtendedBitmap(), if the
 passed bitmap is not an extended bitmap just pass it on to the next render stage directly.
@@ -340,7 +340,7 @@
 	}
 
-/** If the passed bitmap is an extended bitmap of type 0x10285A78, draw it to the 
+/** If the passed bitmap is an extended bitmap of type 0x39b9273e, draw it to the 
 stored graphics context of the next render stage using DrawExtendedBitmap(), if the
 passed bitmap is not an extended bitmap just pass it on to the next render stage directly.
@@ -362,7 +362,7 @@
 	}
 
-/** If the passed bitmap or mask bitmap is an extended bitmap of type 0x10285A78
+/** If the passed bitmap or mask bitmap is an extended bitmap of type 0x39b9273e
 convert it to a normal bitmap before calling DrawBitmapMasked(), normal bitmaps
 are passed straight through to the next render stage without conversion.
@@ -755,7 +755,7 @@
 	}
 
-/** If the passed bitmap is an extended bitmap of type 0x10285A78
+/** If the passed bitmap is an extended bitmap of type 0x39b9273e
 convert the extended bitmap to a normal bitmap and set the converted bitmap
 as the current brush pattern. If the passed bitmap is a normal
@@ -768,7 +768,7 @@
 	}
 
-/** If the passed bitmap handle refers to an extended bitmap of type 0x10285A78
+/** If the passed bitmap handle refers to an extended bitmap of type 0x39b9273e
 convert the extended bitmap to a normal bitmap and set the converted bitmap
 as the current brush pattern. If the passed bitmap handle refers to a normal